==> bluedevil-2.1.1.tar.xz: bluedevil-2.1.1/src/sendfile/pages/selectfilespage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2010-2011 Alejandro Fiestas Olivares <afiestas@kde.org>     *
 * Copyright (C) 2010-2011 UFO Coders <info@ufocoders.com>                   *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef SELECTFILESPAGE_H
#define SELECTFILESPAGE_H

#include <QWizardPage>

class QWizard;
class KFileWidget;

class SelectFilesPage : public QWizardPage
{
Q_OBJECT
public:
    SelectFilesPage(QWidget* parent = 0);

    virtual bool isComplete() const;

private Q_SLOTS:
    void selectionChanged();

private:
    KFileWidget *m_files;
};

#endif // SELECTFILESPAGE_H

==> bluedevil-5.2.95.tar.xz: bluedevil-5.2.95/src/sendfile/pages/selectfilespage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2010-2011 Alejandro Fiestas Olivares <afiestas@kde.org>     *
 * Copyright (C) 2010-2011 UFO Coders <info@ufocoders.com>                   *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef SELECTFILESPAGE_H
#define SELECTFILESPAGE_H

#include <QWizardPage>

class QWizard;
class KFileWidget;

class SelectFilesPage : public QWizardPage
{
    Q_OBJECT

public:
    explicit SelectFilesPage(QWidget *parent = 0);

    bool isComplete() const Q_DECL_OVERRIDE;

private Q_SLOTS:
    void selectionChanged();

private:
    KFileWidget *m_files;
};

#endif // SELECTFILESPAGE_H
